@@ -22,6 +22,7 @@ RESERVED_KEYWORDS = [
     "data",
     "json",
     "upload_file",
+    "pipe_from",
     "download_file",
     "pipe_to",
     "timeout",
@@ -60,6 +61,7 @@ def _temporarily_add_back_dashes_to_param_definitions(f):
         data=None,
         json=None,
         upload_file=None,
+        pipe_from=None,
         download_file=None,
         pipe_to=None,
         timeout=None,
@@ -85,6 +87,7 @@ def _temporarily_add_back_dashes_to_param_definitions(f):
             data,
             json,
             upload_file,
+            pipe_from,
             download_file,
             pipe_to,
             timeout,
@@ -389,6 +392,7 @@ class Method:
         data=None,
         json=None,
         upload_file=None,
+        pipe_from=None,
         download_file=None,
         pipe_to=None,
         timeout=None,
@@ -579,13 +583,20 @@ class Method:
                     )
             media_download = MediaDownload(pipe_to=pipe_to)
 
+        if not upload_file and not pipe_from:
+            media_upload = None
+
         # Process upload_file
         if upload_file:
             media_upload = self._build_upload_media(
-                upload_file, uri, validate, fallback_url=url
+                upload_file, uri, validate, fallback_url=url, pipe_from=None
+            )
+
+        # Process pipe_from
+        if pipe_from:
+            media_upload = self._build_upload_media(
+                upload_file, uri, validate, fallback_url=url, pipe_from=pipe_from
             )
-        else:
-            media_upload = None
 
         return Request(
             method=self["httpMethod"],
@@ -631,7 +642,7 @@ class Method:
         else:
             return base_url + self["path"]
 
-    def _build_upload_media(self, upload_file, qualified_url, validate, fallback_url):
+    def _build_upload_media(self, upload_file, qualified_url, validate, fallback_url, pipe_from):
         if not self["supportsMediaUpload"]:
             if validate:
                 raise ValidationError(
@@ -660,6 +671,7 @@ class Method:
 
         return MediaUpload(
             upload_file,
+            pipe_from=pipe_from,
             upload_path=media_upload_url,
             max_size=max_size,
             mime_range=mime_range,
