@@ -46,6 +46,7 @@ class AiohttpSession(ClientSession, AbstractSession):
             json = None
             download_file = None
             upload_file = None
+            pipe_from = None
             pipe_to = None
 
             # If downloading file:
@@ -89,6 +90,7 @@ class AiohttpSession(ClientSession, AbstractSession):
                 download_file=download_file,
                 pipe_to=pipe_to,
                 upload_file=upload_file,
+                pipe_from=pipe_from,
                 session_factory=session_factory,
             )
 
